
# Examples

This directory contains examples of various `ctc` utlities

- [cli_examples]() usage of cli commands
- [evm_examples]() usage of utilties for events, erc20s, and other high level standards
- [protocol_examples]() usage of utilities for protocols like Uniswap and Chainlink
- [rpc_examples]() usage of utilities for making rpc calls
- [directory_examples]() usage of utilities for getting token and contract addresses
- [abi_examples]() usage of utilities for encoding and decoding abi data

